# Overview of Numba integrators

[https://pypi.org/project/numba-integrators][1]
[https://pypi.org/project/numba-integrators][2]
[https://pypi.org/project/numba-integrators][3]
[https://pypi.org/project/numba-integrators][4]

Numerical integrators using Numba

# Changelog <!-- omit in toc -->

## 0.0.2 2023-05-07 <!-- omit in toc -->

- Setup

[1]: <![PyPI Package latest release](https://img.shields.io/pypi/v/numba-integrators.svg)> ""
[2]: <![PyPI Wheel](https://img.shields.io/pypi/wheel/numba-integrators.svg)> ""
[3]: <![Supported versions](https://img.shields.io/pypi/pyversions/numba-integrators.svg)> ""
[4]: <![Supported implementations](https://img.shields.io/pypi/implementation/numba-integrators.svg)> ""
